%undefine _missing_build_ids_terminate_build

%if 0%{?rhel} > 5
%define openmpiversion  1.6.3
%else
%define openmpiversion  1.3.3
%endif
%define openmpiflavor gcc
%define openmpinversion %( echo %{openmpiversion} | tr -d . )

%define destdir /usr/local/%{rname}/openmpi-%{openmpiversion}/%{version}

# type: string (root path to install modulefiles)
%{!?modulefile_path: %define modulefile_path /usr/local/share/Modules/modulefiles/%{name}}
# type: string (subdir to install modulefile)
%{!?modulefile_subdir: %define modulefile_subdir openmpi-%{openmpiversion}}
# type: string (name of modulefile)
%{!?modulefile_name: %define modulefile_name %{version}}
%define openmpiloadmodule module load openmpi/%{openmpiflavor}

%define rname hpctoolkit
%define	rrel r4197
Version:	5.3.2
%define		nversion %( echo %{version} | tr -d . )
Name:		%{rname}%{nversion}-openmpi%{openmpinversion}
Release:	1.%{rrel}%{?dist}
Summary:	Integrated suite of tools for measurement and analysis of program performance

Group:		Development/Libraries
License:	BSD
URL:		http://hpctoolkit.org/
Source0:	https://hpctoolkit.googlecode.com/files/hpctoolkit-%{version}-%{rrel}.tar.gz
Source1:	https://hpctoolkit.googlecode.com/files/hpctoolkit-externals-%{version}-%{rrel}.tar.gz
BuildRoot:	%(mktemp -ud %{_tmppath}/%{name}-%{version}-%{release}-XXXXXX)
# because it builds its own versions of some of these libraries we do not want it to provide some of this stuff
AutoReqProv:	0

BuildRequires:	libxml2-devel papi-devel
BuildRequires:  openmpi-%{openmpiflavor}-devel = %{openmpiversion}
Requires:       environment-modules
Requires:       openmpi-%{openmpiflavor}-runtime >= %{openmpiversion}
Requires:	libxml2 papi libstdc++

%description
HPCToolkit is an integrated suite of tools for measurement and analysis of 
program performance on computers ranging from multicore desktop systems to the 
nation's largest supercomputers. By using statistical sampling of timers and 
hardware performance counters, HPCToolkit collects accurate measurements of a
program's work, resource consumption, and inefficiency and attributes them to
the full calling context in which they occur. HPCToolkit works with
multilingual, fully optimized applications that are statically or dynamically
linked. Since HPCToolkit uses sampling, measurement has low overhead (1-5%)
and scales to large parallel systems. HPCToolkit's presentation tools enable
rapid analysis of a program's execution costs, inefficiency, and scaling 
characteristics both within and across nodes of a parallel system. HPCToolkit 
supports measurement and analysis of serial codes, threaded codes (e.g. 
pthreads, OpenMP), MPI, and hybrid (MPI+threads) parallel codes.

%package doc
Summary:	HPCToolkit documentation
Group:		Development/Libraries
Requires:	%{name} = %{version}
AutoReqProv:	0

%description doc
HPCToolkit documentation

%package devel
Summary:	Development libraries and include files for HPCToolkit
Group:		Development/Libraries
Requires:	%{name} = %{version}
Requires:	papi-devel libxml2-devel openmpi-%{openmpiflavor}-devel = %{openmpiversion}
AutoReqProv:	0

%description devel
Development libraries and include files for HPCToolkit

%prep
%setup -q -n %{name}-%{version} -c -a 1
# let's make it easier on ourselves
mv hpctoolkit-%{version}-%{rrel} hpctoolkit
mv hpctoolkit-externals-%{version}-%{rrel} hpctoolkit-externals

%build
# configure openmpi
. /etc/profile.d/modules.sh
module load openmpi
# build pre-requisites
cd hpctoolkit-externals
mkdir INSTALL
TEMPDEST=`pwd`/INSTALL
mkdir BUILD && cd BUILD
../configure --prefix=$TEMPDEST --with-libxml2=/usr
make %{?_smp_mflags} install
cd ../../hpctoolkit
mkdir BUILD && cd BUILD
../configure MPICXX=mpiCC MPICC=mpicc MPIF77=mpif77 --prefix=%{destdir} \
     --with-externals=$TEMPDEST --with-papi=/usr
make

%install
rm -rf %{buildroot}
# configure openmpi
. /etc/profile.d/modules.sh
module load openmpi
cd hpctoolkit/BUILD
make install DESTDIR=%{buildroot}
# rename back man pages
pushd %{buildroot}%{destdir}/share/man/man1
rename 1hpctoolkit 1 *
popd

mkdir -p $RPM_BUILD_ROOT/%{modulefile_path}/%{modulefile_subdir}
cat <<EOF >$RPM_BUILD_ROOT/%{modulefile_path}/%{modulefile_subdir}/%{version}
#%Module

proc ModulesHelp { } {
   puts stderr "This module adds HPCToolkit %{version} to various paths"
}

module-whatis   "Sets up HPCToolkit %{version} in your environment"

%{openmpiloadmodule}
prepend-path PATH "%{destdir}/bin"
setenv HPCTOOLKIT "%{destdir}"
prepend-path MANPATH "%{destdir}/man"
EOF


%clean
rm -rf %{buildroot}


%files
%defattr(-,root,root,-)
%dir /usr/local/%{rname}
%dir /usr/local/%{rname}/openmpi*
%dir %{destdir}
%dir %{destdir}/lib
%dir %{destdir}/lib/hpctoolkit
%{destdir}/lib/hpctoolkit/*.so.*
%dir %{destdir}/lib/hpctoolkit/ext-libs
%{destdir}/lib/hpctoolkit/ext-libs/*.so.*
%dir %{destdir}/lib/hpctoolkit/monitor
%{destdir}/lib/hpctoolkit/monitor/*.so.*
%{destdir}/libexec
%dir %{destdir}/share
%{destdir}/share/hpctoolkit
%dir %{destdir}/bin
%{destdir}/bin/hpcrun
%{destdir}/bin/hpcrun-flat
%dir /usr/local/share/Modules/modulefiles/%{name}
%dir %{modulefile_path}
%dir %{modulefile_path}/%{modulefile_subdir}
%{modulefile_path}/%{modulefile_subdir}/%{version}

%files doc
%defattr(-,root,root,-)
%{destdir}/share/doc
%{destdir}/share/man

%files devel
%defattr(-,root,root,-)
%{destdir}/include
%{destdir}/lib/hpctoolkit/*.la
%{destdir}/lib/hpctoolkit/*.a
%{destdir}/lib/hpctoolkit/*.so
%{destdir}/lib/hpctoolkit/*.o
%{destdir}/lib/hpctoolkit/ext-libs/*.la
%{destdir}/lib/hpctoolkit/ext-libs/*.a
%{destdir}/lib/hpctoolkit/ext-libs/*.so
%{destdir}/lib/hpctoolkit/monitor/*.so
%{destdir}/lib/hpctoolkit/plugins
%{destdir}/bin/hpclink
%{destdir}/bin/hpcprof
%{destdir}/bin/hpcprof-flat
%{destdir}/bin/hpcprof-mpi
%{destdir}/bin/hpcproftt
%{destdir}/bin/hpcstruct
%{destdir}/bin/hpcsummary

%changelog
* Tue Sep 24 2013 Josko Plazonic <plazonic@math.princeton.edu>
- initial build
